function LevelCurve2d(P, V0, NbP)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% Function which draws the level curve associated to a 2 dimensional
% Lyapunov funtion.
%
% It takes as Input : 
% P : Definite Positive Matrix (Lyapunov function)
% V0 : value of the level curve
% NbP : nb de point
%
% Last Modification 13/07/2010 by V. Andrieu
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% On rcupre les valeurs propres de P
ev = eig(P); 
% On a c / min(ev) > |x|*|x|, du coup on peut choisir les
% bornes de la grille
a = sqrt(V0 / min(ev))+0.5;
Pas = 2*a/NbP;

% On fait la grille pour x1 et x2 :
[x1, x2] = meshgrid(-a:Pas:a); 

% On choisit l'indice de la premiere variable :
i = floor(NbP/2);

% On prent les vecteurs unitaires :
e1 = [1, 0]';
e2 = [0, 1]';

% On calcul la valeur de x^TPx pour chacun des points de la grille
z = x2.*x2.*(e2'*P*e2) + x1.*x1.*(e1'*P*e1) +  2*x1.*x2.*(e1'*P*e2);
[c,h] = contour(x1, x2, z, [V0, V0], 'LineWidth',2);

return