%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    This is the M-files of a simulation in the paper entitled
% Global asymmptotic stabilizing feedback law for a system
% satifying two different sector conditions
%
% Associated to Example 1
%
% Last Modification 13/07/2010 by V. Andrieu
%
% In this M-file we integrate the model employing the local controller
% developped following the procedure of the paper
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Data of the integration
TSimuPos = 10; % Time of the simulation in positive time
TSimuNeg = -10; % Time of the simulation in negative time
dt = 0.001; % Stepsize of the integration
NbIter = round((TSimuPos-TSimuNeg)/dt);
% Vector of time    
t = zeros(NbIter,1);

% Initial index of the state vector
IndexZero = round((-TSimuNeg)/dt);

% Parameter of the size of the arrow in term of iterations
SizeArrow = 1.5;
SizeEsp = 2.5*SizeArrow;

%Intial value of the state
x10 = [15.1;17]; 
x20 = [0;0]; 

% Parameter describing the size of the zoom
Xm=2*max(x10);
Ym=Xm;

NbInitVal = size(x10,1);

% New figure showing the local controller
scrsz = get(0,'ScreenSize');
figure('Position',[scrsz(4)/2 scrsz(4)/2 scrsz(3)/3 scrsz(4)/3],'name','Local Controller')

for ll=1:NbInitVal
    
    xv = zeros(2,NbIter);
    xv(:,IndexZero) = [x10(ll); x20(ll)];

    for ii=IndexZero:NbIter
   %% Integration when using the local contoller in positive time
        x = xv(:,ii);
        x1 = x(1);
        x2 = x(2);
    
        % The global controller
        u=K0*x + J0*Phi(x1,x2)/eta0;
        % Integration of the model
        dxdt = +A*x + B*u + G*Phi(x1,x2);
        xv(:,ii+1) = x + dxdt*dt;
    end
    for ii=0:IndexZero-2
   %% Integration when using the local contoller in negative time
        x = xv(:,IndexZero-ii);
        x1 = x(1);
        x2 = x(2);
    
        % The global controller
        u=K0*x + J0*Phi(x1,x2)/eta0;
        % Integration of the model
        dxdt = -A*x - B*u - G*Phi(x1,x2);
        xv(:,IndexZero-ii-1) = x + dxdt*dt;
    end

%% Plot of the evolution of the trajectories with some arrows showing the
%% flow

    hold on;
    if ll==1
        plot(xv(1,:),xv(2,:),'r','linewidth',1);
    else
        plot(xv(1,:),xv(2,:),'c','linewidth',1);
    end
    d=0;
    for jj=2:NbIter
        norme=sqrt((xv(1,jj)-xv(1,jj-1))^2 + (xv(2,jj)-xv(2,jj-1))^2);
        d=d+norme;
        if d>SizeEsp
            d=0;        
            
            x1 = xv(1,jj);
            y1 = x1 + (xv(1,jj) - xv(1,jj-1))/norme * SizeArrow;
            x2 = xv(2,jj);
            y2 = x2 +(xv(2,jj) - xv(2,jj-1))/norme * SizeArrow;
        
            f1 = [y1, x1 + 2/3*(y1-x1) - 1/3*(y2-x2)];
            f2 = [y2, x2 + 2/3*(y2-x2) + 1/3*(y1-x1)];
        
            g1 = [y1, x1 + 2/3*(y1-x1) + 1/3*(y2-x2)];
            g2 = [y2, x2 + 2/3*(y2-x2) - 1/3*(y1-x1)];
            hold on;
            plot([x1,y1],[x2,y2],'linewidth',1);
            hold on;    
            plot(f1,f2,'linewidth',1);    
            hold on;
            plot(g1,g2,'linewidth',1);
            AXIS([-Xm +Xm -Ym +Ym])
        end
    end
    
 

end

hold on;
plot([Xm,-Xm],[0,0], '--k');
hold on;
plot([0,0],[Ym,-Ym], '--k');
hold on;
LevelCurve2d(P0,R0,100);
return
