%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    This is the M-files of a simulation in the paper entitled
% Global asymmptotic stabilizing feedback law for a system
% satifying two different sector conditions
%
% Associated to Example 1
%
% Last Modification 13/07/2010 by V. Andrieu
%
% In this M-file we integrate the model employing the non-local controller
% developped following the procedure of the paper
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Data of the integration
TSimu = 50; % Time of the simulation
dt = 0.005; % Stepsize of the integration
NbIter = TSimu/dt;
% Vector of time    
t = zeros(NbIter,1);

% Parameter of the size of the arrow in term of iterations
SizeArrow = 0.03;
SizeEsp = 2.5*SizeArrow;

%Intial value of the state
%x10 = [-0.2;-4;1;2]; 
%x20 = [-0.5;-4;-2;-4]; 
x10 = [-15;0;0;15]; 
x20 = [-15;-15;15;15]; 



% Parameter describing the size of the zoom
Xm=15;
Ym=Xm;
XmZoom = 0.5;

NbInitVal = size(x10);

% New figure showing the Non-local controller
scrsz = get(0,'ScreenSize');
figure('Position',[scrsz(4)/2 scrsz(4)/5 scrsz(3)/3 scrsz(4)/3],'name','Non-local Controller')

for ll=1:NbInitVal
    
    xv = zeros(2,NbIter);
    xv(:,1) = [x10(ll); x20(ll)];

    for ii=1:NbIter
   %% Integration when using the local contoller
        x =  xv(:,ii);
        x1=x(1);
        x2=x(2);
        
        %Nx = sqrt(x'*x);
        %lbda = Nx / (10 + Nx);
        % Nonlinear function 
        %phi = 1/2*(lbda*(Si*x + Ti) + (1-lbda)*S0*x);
    
        % The global controller
        u=Ki*x + Ji*Phi(x1,x2)/etai + Li/taui;
        % Integration of the model
        dxdt = A*x + B*u + G*Phi(x1,x2);
        xv(:,ii+1) = x + dxdt*dt;
    end

%% Plot of the evolution of the trajectories in the two cases

    
    subplot(2,1,1);
    plot(xv(1,:),xv(2,:),'r','linewidth',1);
    hold on;
    subplot(2,1,2);
    plot(xv(1,:),xv(2,:),'r','linewidth',1);
    d=0;
    for jj=2:NbIter
        norme=sqrt((xv(1,jj)-xv(1,jj-1))^2 + (xv(2,jj)-xv(2,jj-1))^2);
        d=d+norme;
        if d>SizeEsp
            d=0;        
            %Pente = (xv(1,jj) - xv(1,jj-1))/(xv(2,jj) - xv(2,jj-1));
            x1 = xv(1,jj);
            y1 = x1 + (xv(1,jj) - xv(1,jj-1))/norme * SizeArrow;
            x2 = xv(2,jj);
            y2 = x2 +(xv(2,jj) - xv(2,jj-1))/norme * SizeArrow;
        
            f1 = [y1, x1 + 2/3*(y1-x1) - 1/3*(y2-x2)];
            f2 = [y2, x2 + 2/3*(y2-x2) + 1/3*(y1-x1)];
        
            g1 = [y1, x1 + 2/3*(y1-x1) + 1/3*(y2-x2)];
            g2 = [y2, x2 + 2/3*(y2-x2) - 1/3*(y1-x1)];
            hold on;
            subplot(2,1,1);
            plot([x1,y1],[x2,y2],'linewidth',1);
            hold on;    
            subplot(2,1,1);
            plot(f1,f2,'linewidth',1);    
            hold on;
            subplot(2,1,1);
            plot(g1,g2,'linewidth',1);
            
            subplot(2,1,2);
            plot([x1,y1],[x2,y2],'linewidth',1);
            hold on;    
            subplot(2,1,2);
            plot(f1,f2,'linewidth',1);    
            hold on;
            subplot(2,1,2);
            plot(g1,g2,'linewidth',1);
        end
    end
    
 

end
subplot(2,1,1);
hold on;
plot([Xm,-Xm],[0,0], '--k');
hold on;
plot([0,0],[Ym,-Ym], '--k');
hold on;
LevelCurve2d(Pi,ri,100);
AXIS([-Xm +Xm -Ym +Ym])


subplot(2,1,2);
hold on;
plot([Xm,-Xm],[0,0], '--k');
hold on;
plot([0,0],[Ym,-Ym], '--k');
hold on;
LevelCurve2d(Pi,ri,100);
AXIS([-XmZoom +XmZoom -XmZoom +XmZoom])
return
